######
# Author: Shingo SHIMIZU, NIED,JAPAN
# 2021.03.21
############################################################
import sys
import os
import subprocess


from read_NC import read_NC,get_unitname,get_date_utc,get_date_jst
from make_grd_GMT import make_grd_GMT
from vertical_cross_section import vertical_cross_section
from vertical_cross_section import change_input_ver_cross
from draw_GMT import draw_GMT, set_deg_per1km,draw_GMT_vertical

def main():

    if len(sys.argv) < 3:
        print ("ARGV error: infile var [t] [k]")
        exit(1)

    infile     = sys.argv[1]

    if not os.path.exists(infile):
        print ("infile does not exist \n",infile)
        exit(1)

    varname    = sys.argv[2]
    
    print (len(sys.argv))

    if len(sys.argv) >= 4:
        t = int(sys.argv[3])
    else :
        t = 0

    if len(sys.argv) >= 5:
        k = int(sys.argv[4])
    else :
        k = 0



    # read NETCDF data to get 2D dataset
    data = read_NC(infile,varname,t,k)
    lon   = read_NC(infile,'LON')
    lat   = read_NC(infile,'LAT')
    udat = read_NC(infile,"U",t,k)
    vdat = read_NC(infile,"V",t,k)

    lev            = read_NC(infile,"ALT")
    height       = lev[k]
    unit_name = get_unitname(infile,varname)
    date          = get_date_utc(infile,t)
#    date          = get_date_jst(infile,t)
 
    # make GRD file for 2-dimensional distribution
    outgrd = varname + "_HORI.grd"
    make_grd_GMT(data,outgrd,lon,lat)
    make_grd_GMT(udat,"U_HORI.grd",lon,lat)
    make_grd_GMT(vdat,"V_HORI.grd",lon,lat)

    # set 1 km -> x degrees in longitude around analysis domain
    lon_per_1km = set_deg_per1km(lat)


    # input setting for vertical cross section
    slon_ver       =   138.56
    slat_ver        =    35.3
    distance_ver =   40.0 # km
    rotate_ver     =    29.0 # deg
    
    cross_section_Start_End = change_input_ver_cross(slon_ver,slat_ver,\
                              distance_ver,rotate_ver,lon_per_1km)

    #  vertical cross section (data creation)
    vertical_cross_section(infile,varname,cross_section_Start_End,t,\
                           need_vertical_interp="YES",\
                           lon_per_1km=lon_per_1km,textout="NO",\
                           u="U",v="V",w="W",\
                           addvar="non",uv_along_line="UVA")

    # draw GMT for vertical cross section
    shade     = varname + "_VER.grd"
    shade_col = varname + ".cpt"
    VFig_TITLE= "vertical cross seciton of " + varname + "   T= " + date
    draw_GMT_vertical(shade=shade,shade_col=shade_col,\
                      cont="non", cont_info="-C1 -L0/10 -W4/red",
                      u="UVA_VER.grd",w="W_VER.grd",bottom=0.0,\
                      top=10.0, start=0.0,end=distance_ver,\
                      fsizX=14,fsizZ=7, PS="hoge3.ps", PNG="hoge3.png",\
                      bbase="a10:Distance\(km\):/a1:Height\(km\):neSW",\
                      title=VFig_TITLE,\
                      unit=unit_name, vec_INTV="2/0.5",\
                      vec_info="0.03c/0.11c/0.1c -W3 -G0",\
                      vec_per1cm=48,wamp=5.0,\
                      PNG_yohakuX=5.0, PNG_yohakuY=3.5,PNG_DPI=100.0)

    # draw GMT for horizontal distribution
    HFig_TITLE= varname + " at " + str(height) + " m" + "    T=  " + date
    shade     = varname + "_HORI.grd"
    shade_col = varname + ".cpt"
    draw_GMT(shade=shade, 
             u="U_HORI.grd",
             v="V_HORI.grd",
             shade_col=shade_col, 
             cont_info="-C1 -L0/10 -W4/blue",
             slon=138.42,
             elon=139.8,
             slat=34.7,
             lon_per_1km=lon_per_1km,
             fsizX=14,
             fsizY=13,
             PS="hoge2.ps",
             PNG="hoge2.png",
             bbase="a0.6/0.2neSW",
             JboundArea="tokai kanto tohoku koushinetsu",
             vec_INTV=0.04,
             vec_info="0.03c/0.11c/0.1c -W3 -G0",
             vec_per1cm=48,
             title=HFig_TITLE,
             unit=unit_name,
             obj_draw_data=cross_section_Start_End,
             obj_draw_command="psxy -W8/red -N",
             PNG_yohakuX=5.0, 
             PNG_yohakuY=2.0,
             PNG_DPI=100.0)
    
    #  Merging multiple FIgures as One ##########
    command = "convert -append" + " hoge2.png hoge3.png hoge.png"
    subprocess.run(command,shell=True)



####################################

if __name__ == "__main__":
    main()

